"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { fetchMessages } from "~/server/functions";
import { middleware } from "~/middleware";

export const GET = async (request: NextRequest) => {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const { searchParams } = new URL(request.url);
    const userId: string | null = searchParams.get("userId");
    const partnerId: string | null = searchParams.get("partnerId");
    if (!userId || !partnerId || isNaN(parseInt(userId)) || isNaN(parseInt(partnerId)))
      return NextResponse.json({ message: "Invalid userId or partnerId" }, { status: 400 });
    const messages = await fetchMessages(parseInt(userId), parseInt(partnerId));
    return NextResponse.json(messages);
  } catch (error) {
    console.error('Detailed error:', error);
    if (error instanceof Error) {
      return NextResponse.json({ message: `Error: ${error.message}` }, { status: 500 });
    } else {
      return NextResponse.json({ message: "Unknown error occurred" }, { status: 500 });
    }
  }
};
