"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { sendMessage } from "~/server/functions";
import { middleware } from "~/middleware";

type sendMessageRequest = {
  senderId: number;
  receiverId: number;
  content: string;
  mediaUrl?: string;
  mediaType?: "text" | "image" | "video" | "audio" | "file" | "link";
};

export const POST = async (request: NextRequest) => {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const {
      senderId,
      receiverId,
      content,
      mediaUrl = "",
      mediaType = "text",
    } = await request.json() as sendMessageRequest;
    if (!senderId || !receiverId || !content || isNaN(senderId) || isNaN(receiverId))
      return NextResponse.json({ message: "Missing required fields" }, { status: 400 });
    const message = await sendMessage(senderId, receiverId, content, mediaUrl, mediaType);
    return NextResponse.json(message, { status: 201 });
  } catch (error) {
    console.error(error);
    return NextResponse.json({ message: "Error" }, { status: 500 });
  }
};
