import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { getPartnerByAppleId, checkRelationshipStatusByAppleId } from "~/server/functions";
import { middleware } from "~/middleware";

export const GET = async (request: NextRequest) => {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;

  const appleId = request.nextUrl.searchParams.get('appleId');

  if (!appleId) {
    return NextResponse.json({ message: "Missing required fields" }, { status: 400 });
  }

  try {
    const relationship = await checkRelationshipStatusByAppleId(appleId);
    const partner = await getPartnerByAppleId(appleId);

    return NextResponse.json({ relationship, partner });
  } catch (error) {
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 404 });
    }
    return NextResponse.json({ message: "Error fetching relationship status" }, { status: 500 });
  }
};
