"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { createRelationshipRequest } from "~/server/functions";
import { middleware } from "~/middleware";

type CreateRequestRequest = {
  userId: number;
  targetUserId: number;
}

export async function POST(request: NextRequest) {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const { userId, targetUserId } = await request.json() as CreateRequestRequest;
    console.log("Received request:", { userId, targetUserId });

    if (!userId || !targetUserId || isNaN(userId) || isNaN(targetUserId))
      return NextResponse.json({ message: "Missing required fields" }, { status: 400 });

    console.log("Creating relationship request for user:", userId);
    const result = await createRelationshipRequest(userId, targetUserId);

    if (result) {
      console.log("Relationship request created successfully");
      return NextResponse.json({ result }, { status: 200 });
    } else {
      throw new Error("Failed to create relationship request");
    }
  } catch (error) {
    console.error("Error in createRequest:", error);
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 400 });
    }
    return NextResponse.json({ message: "Error creating relationship request" }, { status: 500 });
  }
}
