"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { deleteRelationship } from "~/server/functions";
import { middleware } from "~/middleware";

export async function POST(request: NextRequest) {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const { relationshipId } = await request.json() as { relationshipId: string };

    if (!relationshipId || isNaN(parseInt(relationshipId)))
      return NextResponse.json({ message: "Missing required fields" }, { status: 400 });

    console.log("Deleting relationship:", relationshipId);
    const result = await deleteRelationship(parseInt(relationshipId));

    if (result.success) {
      console.log("Relationship deleted successfully");
      return NextResponse.json({ result }, { status: 200 });
    } else {
      throw new Error("Failed to delete relationship");
    }
  } catch (error) {
    console.error("Error in deleteRelationship:", error);
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 400 });
    }
    return NextResponse.json({ message: "Error deleting relationship" }, { status: 500 });
  }
}
