"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { updateRelationshipStatus } from "~/server/functions";
import { middleware } from "~/middleware";

interface UpdateStatusRequest {
  relationshipId: number;
  status: 'accepted' | 'rejected';
}

export async function POST(request: NextRequest) {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const { relationshipId, status } = await request.json() as UpdateStatusRequest;
    console.log("Received request:", { relationshipId, status });

    if (!relationshipId || !status || isNaN(relationshipId))
      return NextResponse.json({ message: "Missing required fields" }, { status: 400 });

    console.log("Updating relationship request:", relationshipId);
    const result = await updateRelationshipStatus(relationshipId, status);

    if (result.success) {
      console.log("Relationship request updated successfully");
      return NextResponse.json({ result }, { status: 200 });
    } else {
      throw new Error("Failed to update relationship request");
    }
  } catch (error) {
    console.error("Error in updateRequest:", error);
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 400 });
    }
    return NextResponse.json({ message: "Error updating relationship request" }, { status: 500 });
  }
}
