"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { createUser } from "~/server/functions";
import { middleware } from "~/middleware";

type CreateUserRequest = {
  appleId: string;
  appleEmail: string;
  fullName: string;
  pushToken: string;
  pfpURL?: string;
};

export async function POST(request: NextRequest) {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const {
      appleId,
      appleEmail,
      fullName,
      pushToken,
      pfpURL = "",
    } = await request.json() as CreateUserRequest;

    // Validate required fields
    if (!appleId || !appleEmail || !fullName || !pushToken) {
      return NextResponse.json(
        { message: "Missing required fields" },
        { status: 400 }
      );
    }

    const user = await createUser(
      appleId,
      appleEmail,
      fullName,
      pushToken,
      pfpURL
    );

    return NextResponse.json(user, { status: 201 });
  } catch (error) {
    console.error("Error creating user:", error);
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 400 });
    }
    return NextResponse.json(
      { message: "An unexpected error occurred" },
      { status: 500 }
    );
  }
}
