"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { getUserByAppleId } from "~/server/functions";
import { middleware } from "~/middleware";

export const GET = async (request: NextRequest) => {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const appleId = request.nextUrl.searchParams.get("appleId");
    if (!appleId)
      return NextResponse.json({ message: "Missing Apple ID" }, { status: 400 });
    const user = await getUserByAppleId(appleId);
    if (user) return NextResponse.json(user);
    else return NextResponse.json({ message: "User not found" }, { status: 404 });
  } catch (error) {
    console.error(error);
    return NextResponse.json({ message: "Error" }, { status: 500 });
  }
};
