'use client';

import React, { useState } from 'react';

export default function TestCreateOrUpdateCountdown() {
  const [relationshipId, setRelationshipId] = useState('');
  const [title, setTitle] = useState('');
  const [date, setDate] = useState('');
  const [result, setResult] = useState<string | null>(null);

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    setResult(null);

    try {
      const response = await fetch('/api/countdown/createOrUpdateCountdown', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          'x-api-key': process.env.NEXT_PUBLIC_API_KEY ?? '',
        },
        body: JSON.stringify({
          relationshipId,
          title,
          date,
        }),
      });
      const data = await response.json() as { message: string };
      setResult(data.message);
    } catch (error) {
      console.error('Error:', error);
      setResult('An error occurred');
    }
  };

  return (
    <main className="flex min-h-screen flex-col items-center justify-center
      bg-gradient-to-b from-pink-500 to-orange-400 text-white cursor-pointer">
      <div className="p-4">
        <h1 className="text-2xl mb-4">Test Create or Update Countdown</h1>
        <form onSubmit={handleSubmit} className="space-y-4">
          <div>
            <label htmlFor="relationshipId" className="block">Relationship ID:</label>
            <input
              type="text"
              id="relationshipId"
              value={relationshipId}
              onChange={(e) => setRelationshipId(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="title" className="block">Title:</label>
            <input
              type="text"
              id="title"
              value={title}
              onChange={(e) => setTitle(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="date" className="block">Date:</label>
            <input
              type="datetime-local"
              id="date"
              value={date}
              onChange={(e) => setDate(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <button type="submit" className="bg-blue-500 text-white p-2 rounded">
            Submit
          </button>
        </form>
        {result && (
          <div className="mt-4 p-2 rounded bg-black">
            Result: {result}
          </div>
        )}
      </div>
    </main>
  );
}
