'use client';

import React, { useState } from 'react';

export default function TestUpdatePFP() {
  const [appleId, setAppleId] = useState('');
  const [file, setFile] = useState<File | null>(null);
  const [result, setResult] = useState<string | null>(null);

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    setResult(null);

    if (!file) {
      setResult('Please select a file');
      return;
    }

    try {
      const formData = new FormData();
      formData.append('appleId', appleId);
      formData.append('file', file);

      const response = await fetch('/api/users/updatePfp', {
        method: 'POST',
        headers: {
          'x-api-key': process.env.NEXT_PUBLIC_API_KEY ?? '',
        },
        body: formData
      });
      const data = await response.json();
      setResult(JSON.stringify(data, null, 2));
    } catch (error) {
      console.error('Error:', error);
      setResult('An error occurred');
    }
  };

  const handleFileChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    if (e.target.files && e.target.files.length > 0) {
      setFile(e.target.files[0]);
    }
  };

  return (
    <main className="flex min-h-screen flex-col items-center justify-center
      bg-gradient-to-b from-pink-500 to-orange-400 text-white cursor-pointer">
      <div className="p-4">
        <h1 className="text-2xl mb-4">Test Update PFP</h1>
        <form onSubmit={handleSubmit} className="space-y-4">
          <div>
            <label htmlFor="appleId" className="block">Apple ID:</label>
            <input
              type="text"
              id="appleId"
              value={appleId}
              onChange={(e) => setAppleId(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="profilepic" className="block">Profile Picture</label>
            <input
              type="file"
              id="profilepic"
              onChange={handleFileChange}
              className="border p-2 w-full bg-black"
              accept="image/*"
              required
            />
          </div>
          <button type='submit' className='bg-blue-500 p-2 rounded'>
            Update PFP
          </button>
        </form>
        {result && (
          <div className='mt-4 p-2 rounded bg-black'>
            <pre>{result}</pre>
          </div>
        )}
      </div>
    </main>
  );
}
